@@ -165,83 +165,41 @@ class Object:
         return audeer.uid(from_string=string)
 
     @staticmethod
+    @audeer.deprecated(
+        removal_version='1.0.0',
+        alternative='audobject.from_dict',
+    )
     def from_dict(
             d: typing.Dict[str, typing.Any],
             root: str = None,
             **kwargs,
-    ) -> 'Object':
-        r"""Create object from dictionary.
-
-        Args:
-            d: dictionary with variables
-            root: if dictionary was read from a file, set to source directory
-            kwargs: additional variables
-
-        Returns:
-            object
-
-        Raises:
-            RuntimeError: if a mandatory argument of the object
-                is missing in the dictionary
-
-        """
-        name = next(iter(d))
-        cls, version, installed_version = utils.get_class(name)
-        params = {}
-        for key, value in d[name].items():
-            params[key] = Object._decode_value(value, **kwargs)
-        return utils.get_object(
-            cls,
-            version,
-            installed_version,
-            params,
-            root,
-            **kwargs,
-        )
+    ) -> 'Object':  # pragma: no cover
+        from audobject.core.api import from_dict
+        return from_dict(d, root, **kwargs)
 
     @staticmethod
+    @audeer.deprecated(
+        removal_version='1.0.0',
+        alternative='audobject.from_yaml',
+    )
     def from_yaml(
             path_or_stream: typing.Union[str, typing.IO],
             **kwargs,
-    ) -> 'Object':
-        r"""Create object from YAML file.
-
-        Args:
-            path_or_stream: file path or stream
-            kwargs: additional variables
-
-        Returns:
-            object
-
-        """
-        if isinstance(path_or_stream, str):
-            with open(path_or_stream, 'r') as fp:
-                return Object.from_yaml(fp, **kwargs)
-        return Object.from_dict(
-            yaml.load(path_or_stream, yaml.Loader),
-            root=os.path.dirname(path_or_stream.name),
-            **kwargs,
-        )
+    ) -> 'Object':  # pragma: no cover
+        from audobject.core.api import from_yaml
+        return from_yaml(path_or_stream, **kwargs)
 
     @staticmethod
+    @audeer.deprecated(
+        removal_version='1.0.0',
+        alternative='audobject.from_yaml_s',
+    )
     def from_yaml_s(
             yaml_string: str,
             **kwargs,
-    ) -> 'Object':
-        r"""Create object from YAML string.
-
-        Args:
-            yaml_string: YAML string
-            kwargs: additional variables
-
-        Returns:
-            object
-
-        """
-        return Object.from_dict(
-            yaml.load(yaml_string, yaml.Loader),
-            **kwargs,
-        )
+    ) -> 'Object':  # pragma: no cover
+        from audobject.core.api import from_yaml_s
+        return from_yaml_s(yaml_string, **kwargs)
 
     @property
     def resolvers(self) -> typing.Dict[str, ValueResolver]:
@@ -368,28 +326,6 @@ class Object:
         """  # noqa: E501
         return yaml.dump(self.to_dict(include_version=include_version))
 
-    @staticmethod
-    def _decode_value(
-            value_to_decode: typing.Any,
-            **kwargs,
-    ) -> typing.Any:
-        r"""Decode value."""
-        if value_to_decode:  # not empty
-            if isinstance(value_to_decode, list):
-                return [
-                    Object._decode_value(v, **kwargs) for v in value_to_decode
-                ]
-            elif isinstance(value_to_decode, dict):
-                name = next(iter(value_to_decode))
-                if isinstance(name, Object) or utils.is_class(name):
-                    return Object.from_dict(value_to_decode, **kwargs)
-                else:
-                    return {
-                        k: Object._decode_value(v, **kwargs) for k, v in
-                        value_to_decode.items()
-                    }
-        return value_to_decode
-
     def _encode_variable(
             self,
             name: str,
